==> piwigo-2.5.1.zip: piwigo/language/it_IT/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Installation'] = 'Installazione';
$lang['Basic configuration'] = 'Configurazione di base';
$lang['Default gallery language'] = 'Lingua predefinita della galleria';
$lang['Database configuration'] = 'Configurazione database';
$lang['Admin configuration'] = 'Configurazione utente Amministratore';
$lang['Start Install'] = 'Inizia l\'installazione';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'l\'indirizzo email deve essere tipo xxx@yyy.eee (esempio: jack@altern.org)';
$lang['Webmaster login'] = 'Nome utente webmaster';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Esso verrà mostrato ai visitatori. E\' necessario per amministrare il vostro sito';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Connessione al server riuscita, ma non è stato possibile connettersi al database.';
$lang['Can\'t connect to server'] = 'Impossibile connettersi al server';
$lang['Host'] = 'Host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost o altro, datovi dal vostro provider';
$lang['User'] = 'Utente';
$lang['user login given by your host provider'] = 'login utente database fornito dal vostro provider';
$lang['Password'] = 'Password';
$lang['user password given by your host provider'] = 'password d\'accesso al database fornita dal vostro provider';
$lang['Database name'] = 'Nome del database';
$lang['also given by your host provider'] = 'anche questo fornito dal vostro provider';
$lang['Database table prefix'] = 'Prefisso tabelle database';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'i nomi delle tabelle del database saranno preceduti da questo prefisso (vi permette di gestire meglio le tabelle)';
$lang['enter a login for webmaster'] = 'inserire un nome utente per il webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'il nome utente del webmaster non può contenere caratteri come \' o "';
$lang['please enter your password again'] = 'reinserire la password';
$lang['Webmaster password'] = 'Password del webmaster';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Da conservare con cura. Permette l\'accesso al pannello d\'amministrazione';
$lang['Password [confirm]'] = 'Password [confermare]';
$lang['verification'] = 'verifica';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Avete bisogno di aiuto? Visitate il <a href="%s">forum di Piwigo</a>.';
$lang['Webmaster mail address'] = 'Indirizzo email del Webmaster';
$lang['Visitors will be able to contact site administrator with this mail'] = 'I visitatori saranno in grado di contattarvi usando questa email';
$lang['PHP 5 is required'] = 'E\' richiesto PHP 5';
$lang['It appears your webhost is currently running PHP %s.'] = 'Sembra che la versione PHP del vostro server sia %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo tenterà di cambiare la configurazione di PHP 5 creando o modificando il file .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Nota: potete cambiare manualmente la configurazione PHP e poi riavviare Piwigo.';
$lang['Try to configure PHP 5'] = 'Provare a configurare PHP 5';
$lang['Sorry!'] = 'Spiacente!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo non è stato in grado di configurare PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Si consiglia di fare riferimento al supporto del vostro provider di hosting e vedere come potete passare a PHP 5 da soli.';
$lang['Hope to see you back soon.'] = 'Speriamo di rivedervi presto.';
$lang['Congratulations, Piwigo installation is completed'] = 'Congratulazioni, l\'installazione di Piwigo è completata';

$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Una soluzione alternativa è quella di copiare il testo della casella sopra e incollarlo nel file "local/config/database.inc.php" (Attenzione: database.inc.php deve contenere solo quello che c\'è nel box sopra, senza nessun ritorno a capo o spazio)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creazione del file di configurazione local/config/database.inc.php fallita.';
$lang['Download the config file'] = 'Scaricare il file di configurazione';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'E\' possibile scaricare il file di configurazione e caricarlo in local/config della vostra installazione di Piwigo.';
$lang['Just another Piwigo gallery'] = 'Una galleria Piwigo in più ';
$lang['Welcome to my photo gallery'] = 'Benvenuti nella mia galleria fotografica';
$lang['Welcome to your new installation of Piwigo!'] = 'Benvenuti sulla vostra nuova installazione di Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Non esitate a consultare i nostri forum se avete un qualunque problema: %s';

?>

==> piwigo-2.7.4.zip: piwigo/language/it_IT/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installazione';
$lang['Basic configuration'] = 'Configurazione di base';
$lang['Default gallery language'] = 'Lingua predefinita della galleria';
$lang['Database configuration'] = 'Configurazione database';
$lang['Admin configuration'] = 'Configurazione utente Amministratore';
$lang['Start Install'] = 'Inizia l\'installazione';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Esso verrà mostrato ai visitatori. E\' necessario per amministrare il vostro sito';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Connessione al server riuscita, ma non è stato possibile connettersi al database.';
$lang['Can\'t connect to server'] = 'Impossibile connettersi al server';
$lang['Host'] = 'Host';
$lang['localhost or other, supplied by your host provider'] = 'localhost o altro, datovi dal vostro provider';
$lang['User'] = 'Utente';
$lang['user login given by your host provider'] = 'login utente database fornito dal vostro provider';
$lang['user password given by your host provider'] = 'password d\'accesso al database fornita dal vostro provider';
$lang['Database name'] = 'Nome del database';
$lang['also given by your host provider'] = 'anche questo fornito dal vostro provider';
$lang['Database table prefix'] = 'Prefisso tabelle database';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'i nomi delle tabelle del database saranno preceduti da questo prefisso (vi permette di gestire meglio le tabelle)';
$lang['enter a login for webmaster'] = 'inserire un nome utente per il webmaster';
$lang['webmaster login can\'t contain characters \' or "'] = 'il nome utente del webmaster non può contenere caratteri come \' o "';
$lang['please enter your password again'] = 'reinserire la password';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Da conservare con cura. Permette l\'accesso al pannello d\'amministrazione';
$lang['Password [confirm]'] = 'Password [confermare]';
$lang['verification'] = 'verifica';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Avete bisogno di aiuto? Visitate il <a href="%s">forum di Piwigo</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'I visitatori saranno in grado di contattarvi usando questa email';
$lang['PHP 5 is required'] = 'E\' richiesto PHP 5';
$lang['It appears your webhost is currently running PHP %s.'] = 'Sembra che la versione PHP del vostro server sia %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo tenterà di cambiare la configurazione di PHP 5 creando o modificando il file .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Nota: potete cambiare manualmente la configurazione PHP e poi riavviare Piwigo.';
$lang['Try to configure PHP 5'] = 'Provare a configurare PHP 5';
$lang['Sorry!'] = 'Spiacente!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo non è stato in grado di configurare PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Si consiglia di fare riferimento al supporto del vostro provider di hosting e vedere come potete passare a PHP 5 da soli.';
$lang['Hope to see you back soon.'] = 'Speriamo di rivedervi presto.';
$lang['Congratulations, Piwigo installation is completed'] = 'Congratulazioni, l\'installazione di Piwigo è completata';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Una soluzione alternativa è quella di copiare il testo della casella sopra e incollarlo nel file "local/config/database.inc.php" (Attenzione: database.inc.php deve contenere solo quello che c\'è nel box sopra, senza nessun ritorno a capo o spazio)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Creazione del file di configurazione local/config/database.inc.php fallita.';
$lang['Download the config file'] = 'Scaricare il file di configurazione';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'E\' possibile scaricare il file di configurazione e caricarlo in local/config della vostra installazione di Piwigo.';
$lang['Just another Piwigo gallery'] = 'Una galleria Piwigo in più ';
$lang['Welcome to my photo gallery'] = 'Benvenuti nella mia galleria fotografica';
$lang['Welcome to your new installation of Piwigo!'] = 'Benvenuti sulla vostra nuova installazione di Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Non esitate a consultare i nostri forum se avete un qualunque problema: %s';
?>
